@@ -140,7 +140,6 @@ ev_document_misc_paint_one_page (cairo_t      *cr,
 				 gboolean      highlight,
 				 gboolean      inverted_colors)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkStyleContext *context = gtk_widget_get_style_context (widget);
 	GtkStateFlags state = gtk_widget_get_state_flags (widget);
         GdkRGBA fg, bg, shade_bg;
@@ -157,12 +156,6 @@ ev_document_misc_paint_one_page (cairo_t      *cr,
         gtk_symbolic_color_unref (c2);
 
 	gdk_cairo_set_source_rgba (cr, highlight ? &fg : &shade_bg);
-#else
-	GtkStyle    *style = gtk_widget_get_style (widget);
-	GtkStateType state = gtk_widget_get_state (widget);
-
-	gdk_cairo_set_source_color (cr, highlight ? &style->text[state] : &style->dark[state]);
-#endif
 	gdk_cairo_rectangle (cr, area);
 	cairo_fill (cr);
 
@@ -177,11 +170,7 @@ ev_document_misc_paint_one_page (cairo_t      *cr,
 			 area->height - (border->top + border->bottom));
 	cairo_fill (cr);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gdk_cairo_set_source_rgba (cr, &bg);
-#else
-	gdk_cairo_set_source_color (cr, &style->mid[state]);
-#endif
 	cairo_rectangle (cr,
 			 area->x,
 			 area->y + area->height - (border->bottom - border->top),
@@ -426,14 +415,13 @@ ev_document_misc_format_date (GTime utime)
 	return g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
 }
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 void
 ev_document_misc_get_pointer_position (GtkWidget *widget,
                                        gint      *x,
                                        gint      *y)
 {
 #if GTK_CHECK_VERSION (3, 20, 0)
-		GdkSeat *seat;
+        GdkSeat *seat;
 #else
         GdkDeviceManager *device_manager;
 #endif
@@ -448,7 +436,7 @@ ev_document_misc_get_pointer_position (GtkWidget *widget,
         if (!gtk_widget_get_realized (widget))
                 return;
 
-#if GTK_CHECK_VERSION(3, 20, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
         seat = gdk_display_get_default_seat (gtk_widget_get_display (widget));
         device_pointer = gdk_seat_get_pointer (seat);
 #else
@@ -468,5 +456,3 @@ ev_document_misc_get_pointer_position (GtkWidget *widget,
         if (y)
                 *y -= allocation.y;
 }
-#endif
-
