@@ -109,14 +109,10 @@ typedef struct _EvHeightToPageCache {
 } EvHeightToPageCache;
 
 struct _EvView {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkContainer layout;
 
 	/* Container */
 	GList *children;
-#else
-	GtkLayout layout;
-#endif
 
 	EvDocument *document;
 
@@ -140,12 +136,10 @@ struct _EvView {
 	/* Scrolling */
 	GtkAdjustment *hadjustment;
 	GtkAdjustment *vadjustment;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	/* GtkScrollablePolicy needs to be checked when
 	* driving the scrollable adjustment values */
 	guint hscroll_policy : 1;
 	guint vscroll_policy : 1;
-#endif
 
 	gint scroll_x;
 	gint scroll_y;	
@@ -207,15 +201,11 @@ struct _EvView {
 	EvMapping *synctex_result;
 
 	/* Accessibility */
-	gboolean a11y_enabled;
+	AtkObject *accessible;
 };
 
 struct _EvViewClass {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkContainerClass parent_class;
-#else
-	GtkLayoutClass parent_class;
-#endif
 
 	void    (*binding_activated)	  (EvView         *view,
 					   GtkScrollType   scroll,
@@ -240,6 +230,23 @@ void _get_page_size_for_scale_and_rotation (EvDocument *document,
 					    gint        rotation,
 					    gint       *page_width,
 					    gint       *page_height);
+void _ev_view_transform_view_point_to_doc_point (EvView       *view,
+						 GdkPoint     *view_point,
+						 GdkRectangle *page_area,
+						 double       *doc_point_x,
+						 double       *doc_point_y);
+void _ev_view_transform_view_rect_to_doc_rect (EvView       *view,
+					       GdkRectangle *view_rect,
+					       GdkRectangle *page_area,
+					       EvRectangle  *doc_rect);
+void _ev_view_transform_doc_point_to_view_point (EvView   *view,
+						 int       page,
+						 EvPoint  *doc_point,
+						 GdkPoint *view_point);
+void _ev_view_transform_doc_rect_to_view_rect (EvView       *view,
+					       int           page,
+					       EvRectangle  *doc_rect,
+					       GdkRectangle *view_rect);
 
 #endif  /* __EV_VIEW_PRIVATE_H__ */
 
