@@ -24,10 +24,6 @@
 
 #include "ev-progress-message-area.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 #define EV_PROGRESS_MESSAGE_AREA_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_PROGRESS_MESSAGE_AREA, EvProgressMessageAreaPrivate))
 
@@ -89,13 +85,17 @@ ev_progress_message_area_init (EvProgressMessageArea *area)
 
 	contents = _ev_message_area_get_main_box (EV_MESSAGE_AREA (area));
 	
-	vbox = gtk_vbox_new (FALSE, 6);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	
 	area->priv->label = gtk_label_new (NULL);
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_ellipsize (GTK_LABEL (area->priv->label),
 				 PANGO_ELLIPSIZE_END);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (area->priv->label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (area->priv->label), 0.0, 0.5);
+#endif
 	gtk_box_pack_start (GTK_BOX (vbox), area->priv->label, TRUE, TRUE, 0);
 	gtk_widget_show (area->priv->label);
 
